/*
 * Copyright (c) 2010 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution  and  use  in  source  and binary  forms,  with  or  without
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice and this list of conditions.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice and  this list of  conditions in the  documentation and/or
 *      other materials provided with the distribution.
 *
 * THE SOFTWARE  IS PROVIDED "AS IS"  AND THE AUTHOR  DISCLAIMS ALL WARRANTIES
 * WITH  REGARD   TO  THIS  SOFTWARE  INCLUDING  ALL   IMPLIED  WARRANTIES  OF
 * MERCHANTABILITY AND  FITNESS.  IN NO EVENT  SHALL THE AUTHOR  BE LIABLE FOR
 * ANY  SPECIAL, DIRECT,  INDIRECT, OR  CONSEQUENTIAL DAMAGES  OR  ANY DAMAGES
 * WHATSOEVER  RESULTING FROM  LOSS OF  USE, DATA  OR PROFITS,  WHETHER  IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR  OTHER TORTIOUS ACTION, ARISING OUT OF OR
 * IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _VELODYNE_STRUCT_H
#define _VELODYNE_STRUCT_H

#include "velodyneClient.h"

/***********************************************************************/
/* Some general constants */
#define	VELODYNE_MAX_STRLEN	128

/***********************************************************************/
/* Initialization parameters */

typedef enum velodyneMode {VELODYNE_LIVE,
			   VELODYNE_FROM_FILE} velodyneMode;
typedef enum velodyneBoolean {VELODYNE_FALSE,
			      VELODYNE_TRUE} velodyneBoolean;


#define VELODYNE_DEFAULT_MODE		VELODYNE_FROM_FILE
#define VELODYNE_DEFAULT_USE_POM	VELODYNE_FALSE
#define VELODYNE_DEFAULT_POS_POSTER		"pomPos"
#define VELODYNE_DEFAULT_SENSOR_POS_POSTER	"pomVelodyneFramePos"
#define VELODYNE_DEFAULT_INPUT_FILENAME	"/tmp/velodyne.dump"

typedef struct velodyneInitParams {
  velodyneMode		mode;
  velodyneBoolean	usePom;
  char			posPoster[VELODYNE_MAX_STRLEN];
  char			sensorPosPoster[VELODYNE_MAX_STRLEN];
  char			inputFileName[VELODYNE_MAX_STRLEN];
} VelodyneInitParams;

/***********************************************************************/
/* Save parameters */
#define	VELODYNE_DEFAULT_BASENAME	"/tmp/velodyneDump"
#define VELODYNE_DEFAULT_NUM		0

typedef struct velodyneSaveParams {
    char	baseName[VELODYNE_MAX_STRLEN];
    int		num;
} velodyneSaveParams;

/***********************************************************************/
/* Parameters that define the angular size of a scan IN THE ROBOT FRAME. They
 * are in degrees, because velodyne returns angles in degrees (in hundreth of
 * degrees actually), hence there is no need to deal with degrees/radian
 * conversions. Note also that the two angles are prefixed first/last (and not
 * min/max): these angles define a sector that goes counter-clockwise from
 * firstAngle to lastAngle. 
 * Examples:
 * (-40;40) defines a 80 degrees sector centered on the robot X (forward) axis
 * (-150;150) defines a 150 degrees sector centered on the robot X (forward) axis
 * (-120; -60) defines a 60 degrees sector centered on the robot -Y (rightwards) axis
 * (40;-40) defines a 280 degrees sector centered on the robot -X (backward) axis
 * (150;-150) defines a 60 degrees sector centered on the robot -X (backward) axis
 * (-60; -120) defines a 300 degrees sector centered on the robot Y (leftwards) axis
 * Finally (-180,180) (or the reverse) defines a full 360 degrees scan
 */

#define VELODYNE_ONE_SHOT_FIRST_ANGLE (-180)
#define VELODYNE_ONE_SHOT_LAST_ANGLE (180)

typedef struct velodyneOneShotParams {
  double	firstAngle_degrees;
  double	lastAngle_degrees;
} velodyneOneShotParams;



#endif
